Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1104)

Unified Diff: tools/gn/target_generator.cc

Issue 386943006: Pull buildtools to get GN r282653 (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/gn/filesystem_utils.cc ('k') | ui/ozone/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/gn/target_generator.cc
diff --git a/tools/gn/target_generator.cc b/tools/gn/target_generator.cc
index d38dbd938770bcae8b9858ce5ee30c2f54b99abf..12d09fca1527092d16ff2b249a47e72ce739fe14 100644
--- a/tools/gn/target_generator.cc
+++ b/tools/gn/target_generator.cc
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() {
void TargetGenerator::FillInputs() {
const Value* value = scope_->GetValue(variables::kInputs, true);
if (!value) {
// Older versions used "inputs". Allow use of this variable until
// all callers are updated.
// TODO(brettw) remove this eventually.
- value = scope_->GetValue("inputs", true);
+ value = scope_->GetValue("source_prereqs", true);
if (!value)
return;
« no previous file with comments | « tools/gn/filesystem_utils.cc ('k') | ui/ozone/BUILD.gn » ('j') | no next file with comments »
@@ -163,10 +163,10 @@ void TargetGenerator::FillPublic() {
const Value* value = scope_->GetValue(variables::kInputs, true);
if (!value) {
- // Older versions used "inputs". Allow use of this variable until
+ // Older versions used "source_prereqs". Allow use of this variable until
// all callers are updated.
// TODO(brettw) remove this eventually.

Powered by Google App Engine
This is Rietveld 408576698